import numpy as np

def add_one(number):
    return number + 1
def hi():
    return "hi"

def t1():
    print(np.ones((3,2)))

def t2():
    print(np.__version__)